.new_action: Structure a Scene Action
Description
Structure a Scene Action
Usage
.new_action(check_fn, methods)
Value
A scene_action object, which is a list with components check_fn
and methods.
Arguments
- check_fn
The function that processes the request to determine if an
associated scene should be returned.
- methods
The http methods supported by this action.