.new_shiny_scene: Structure a Shiny Scene
Description
Structure a Shiny Scene
Usage
.new_shiny_scene(ui, actions)
Value
A shiny_scene object, which is a list with components ui and
actions.
Arguments
- ui
The ui to return for this set of actions.
- actions
Zero or more actions required in order to invoke this ui.